Package: bindr
Title: Parametrized Active Bindings
Version: 0.1.2
Authors@R: c(
    person("Kirill", "M\u00fcller", role = c("aut", "cre"), email = "kirill@cynkra.com", comment = c(ORCID = "0000-0002-1416-3412")),
    person("RStudio", role = c("cph", "fnd"))
    )
Description: Provides a simple interface for creating active bindings where the
    bound function accepts additional arguments.
Suggests: testthat
Date: 2024-11-21
BugReports: https://github.com/krlmlr/bindr/issues
URL: https://github.com/krlmlr/bindr, https://krlmlr.github.io/bindr/
RoxygenNote: 7.3.2.9000
License: MIT + file LICENSE
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-11-21 20:34:52 UTC; kirill
Author: Kirill Müller [aut, cre] (<https://orcid.org/0000-0002-1416-3412>),
  RStudio [cph, fnd]
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2024-11-21 21:30:14 UTC
Built: R 4.4.0; ; 2026-07-18 01:00:46 UTC; unix
