Package: bindr
Title: Parametrized Active Bindings
Version: 0.1.3
Authors@R: c(
    person("Kirill", "M\u00fcller", role = c("aut", "cre"), email = "kirill@cynkra.com", comment = c(ORCID = "0000-0002-1416-3412")),
    person("RStudio", role = c("cph", "fnd"))
    )
Description: Provides a simple interface for creating active bindings where the
    bound function accepts additional arguments.
Suggests: testthat
Date: 2025-11-18
BugReports: https://github.com/krlmlr/bindr/issues
URL: https://github.com/krlmlr/bindr, https://krlmlr.github.io/bindr/
RoxygenNote: 7.3.3.9000
License: MIT + file LICENSE
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-12-01 06:53:20 UTC; kirill
Author: Kirill Müller [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1416-3412>),
  RStudio [cph, fnd]
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2025-12-01 07:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 12:55:49 UTC; unix
